pqsfinder(subject, strand = "*", max_len = 50L, min_score = 42L,
run_min_len = 3L, run_max_len = 11L, loop_min_len = 0L,
loop_max_len = 30L, max_bulges = 3L, max_mismatches = 2L,
max_defects = 3L, tetrad_bonus = 45L, bulge_penalty = 20L,
mismatch_penalty = 31L, loop_mean_factor = 1, loop_sd_factor = 1,
run_re = "G{1,5}.{0,5}G{1,5}", custom_scoring_fn = NULL,
use_default_scoring = TRUE, verbose = FALSE)max_bulges +
max_mismatches).subject - Input DNAString object,
score - implicit PQS score, start - PQS start position,
width - PQS width, loop_1 - start pos. of loop #1,
run_2 - start pos. of run #2, loop_2 - start pos. of loop
#2, run_3 - start pos. of run #3, loop_3 - start pos. of
loop #3, run_4 - start pos. of run #4. Return value of the function
has to be new score represented as a single integer value. Please note
that if use_default_scoring is enabled, the custom scoring function
is evaluated AFTER the default scoring system but ONLY IF the default
scoring system resulted in non-zero score (for performance reasons). On
the other hand, when use_default_scoring is disabled, custom
scoring function is evaluated on every PQS.start cnt pqs_sequence score, where start is the PQS
starting position, pqs_sequence shows the PQS sequence structure
with each run surrounded by square brackets and score is the score
assigned to the particular PQS by all applied scoring functions.PQSViews objectpv <- pqsfinder(DNAString("CCCCCCGGGTGGGTGGGTGGGAAAA"))Run the code above in your browser using DataLab